// @shared/stores/editSightStore.ts
import { authInstance, Language } from "@shared";
import { makeAutoObservable, runInAction } from "mobx";

export type SightLanguageInfo = {
  id: number;
  name: string;
  address: string;
  left: { heading: string; body: string };
  right: { heading: string; body: string }[];
};

export type SightCommonInfo = {
  city_id: number;
  city: string;
  latitude: number;
  longitude: number;
  thumbnail: string;
  watermark_lu: string;
  watermark_rd: string;
  left_article: number;
  preview_media: string;
  video_preview: string;
};

export type SightBaseInfo = {
  common: SightCommonInfo;
} & {
  [key in Language]: SightLanguageInfo;
};
class EditSightStore {
  sight: SightBaseInfo = {
    common: {
      city_id: 0,
      city: "",
      latitude: 0,
      longitude: 0,
      thumbnail: "",
      watermark_lu: "",
      watermark_rd: "",
      left_article: 0,
      preview_media: "",
      video_preview: "",
    },
    ru: {
      id: 0,
      name: "",
      address: "",
      left: { heading: "", body: "" },
      right: [],
    },
    en: {
      id: 0,
      name: "",
      address: "",
      left: { heading: "", body: "" },
      right: [],
    },
    zh: {
      id: 0,
      name: "",
      address: "",
      left: { heading: "", body: "" },
      right: [],
    },
  };

  constructor() {
    makeAutoObservable(this);
  }

  hasLoadedCommon = false;
  getSightInfo = async (id: number, language: Language) => {
    if (this.sight[language].id === id) {
      return;
    }

    const response = await authInstance.get(`/sight/${id}`);
    const data = response.data;

    runInAction(() => {
      // Обновляем языковую часть
      this.sight[language] = {
        ...this.sight[language],
        ...data,
      };

      // Только при первом запросе обновляем общую часть
      if (!this.hasLoadedCommon) {
        this.sight.common = {
          ...this.sight.common,
          ...data,
        };
        this.hasLoadedCommon = true;
      }
    });
  };

  updateLeftInfo = (language: Language, heading: string, body: string) => {
    this.sight[language].left.heading = heading;
    this.sight[language].left.body = body;
  };

  clearSightInfo = () => {
    this.sight = {
      common: {
        city_id: 0,
        city: "",
        latitude: 0,
        longitude: 0,
        thumbnail: "",
        watermark_lu: "",
        watermark_rd: "",
        left_article: 0,
        preview_media: "",
        video_preview: "",
      },
      ru: {
        id: 0,
        name: "",
        address: "",
        left: { heading: "", body: "" },
        right: [],
      },

      en: {
        id: 0,
        name: "",
        address: "",
        left: { heading: "", body: "" },
        right: [],
      },

      zh: {
        id: 0,
        name: "",
        address: "",
        left: { heading: "", body: "" },
        right: [],
      },
    };
  };

  updateSightInfo = (
    language: Language,
    content: Partial<SightLanguageInfo | SightCommonInfo>,
    common: boolean = false
  ) => {
    if (common) {
      this.sight.common = {
        ...this.sight.common,
        ...content,
      };
    } else {
      this.sight[language] = {
        ...this.sight[language],
        ...content,
      };
    }
  };
}

export const editSightStore = new EditSightStore();
