import {
  Button,
  TextField,
  Box,
  Autocomplete,
  Typography,
  Paper,
  Tooltip,
  MenuItem,
  Menu as MuiMenu,
} from "@mui/material";
import {
  BackButton,
  TabPanel,
  languageStore,
  Language,
  cityStore,
  editSightStore,
  SelectMediaDialog,
  PreviewMediaDialog,
  SightLanguageInfo,
  SightCommonInfo,
} from "@shared";
import { LanguageSwitcher } from "@widgets";
import { Info, ImagePlus } from "lucide-react";

import { observer } from "mobx-react-lite";
import { useEffect, useState } from "react";

// Мокап для всплывающей подсказки

export const InformationTab = observer(
  ({ value, index }: { value: number; index: number }) => {
    const { cities } = cityStore;
    const [, setIsMediaModalOpen] = useState(false);
    const [mediaId, setMediaId] = useState<string>("");
    const [isPreviewMediaOpen, setIsPreviewMediaOpen] = useState(false);

    const { language } = languageStore;
    const { sight, updateSightInfo } = editSightStore;

    const data = sight[language];
    const common = sight.common;

    const [, setCity] = useState<number>(common.city_id ?? 0);
    const [coordinates, setCoordinates] = useState<string>(`0 0`);

    const token = localStorage.getItem("token");

    // Menu state for each media button
    const [menuAnchorEl, setMenuAnchorEl] = useState<null | HTMLElement>(null);
    const [activeMenuType, setActiveMenuType] = useState<
      "thumbnail" | "watermark_lu" | "watermark_rd" | null
    >(null);
    const [isAddMediaOpen, setIsAddMediaOpen] = useState(false);

    const handleMenuOpen = (
      event: React.MouseEvent<HTMLElement>,
      type: "thumbnail" | "watermark_lu" | "watermark_rd"
    ) => {
      setMenuAnchorEl(event.currentTarget);
      setActiveMenuType(type);
    };

    useEffect(() => {
      // Показывать только при инициализации (не менять при ошибках пользователя)
      if (common.latitude !== 0 || common.longitude !== 0) {
        setCoordinates(`${common.latitude} ${common.longitude}`);
      }
      // если координаты обнулились — оставить поле как есть
    }, [common.latitude, common.longitude]);

    const handleMenuClose = () => {
      setMenuAnchorEl(null);
      setActiveMenuType(null);
    };

    const handleCreateNew = () => {
      handleMenuClose();
    };

    const handleAddMedia = () => {
      setIsAddMediaOpen(true);
      handleMenuClose();
    };

    const handleMediaSelect = () => {
      if (!activeMenuType) return;

      // Close the dialog
      setIsAddMediaOpen(false);
      setActiveMenuType(null);
    };

    const handleChange = (
      language: Language,
      content: Partial<SightLanguageInfo | SightCommonInfo>,
      common: boolean = false
    ) => {
      updateSightInfo(language, content, common);
    };

    return (
      <>
        <TabPanel value={value} index={index}>
          <Box
            sx={{
              display: "flex",
              flexDirection: "column",
              gap: 3,
              position: "relative",
              paddingBottom: "70px" /* Space for save button */,
            }}
          >
            <BackButton />

            <Box
              sx={{
                display: "flex",

                gap: 4, // Added gap between the two main columns
                width: "100%",
                flexDirection: "column",
              }}
            >
              {/* Left column with main fields */}
              <Box
                sx={{
                  flexGrow: 1,
                  display: "flex",
                  width: "80%",
                  flexDirection: "column",
                  gap: 2.5,
                }}
              >
                <TextField
                  label={`Название (${language.toUpperCase()})`}
                  value={data.name}
                  onChange={(e) => {
                    handleChange(language as Language, {
                      name: e.target.value,
                    });
                  }}
                  fullWidth
                  variant="outlined"
                />

                <TextField
                  label="Адрес"
                  value={data.address}
                  onChange={(e) => {
                    handleChange(language as Language, {
                      address: e.target.value,
                    });
                  }}
                  fullWidth
                  variant="outlined"
                />

                <Autocomplete
                  options={cities ?? []}
                  value={
                    cities.find((city) => city.id === common.city_id) ?? null
                  }
                  getOptionLabel={(option) => option.name}
                  onChange={(_, value) => {
                    setCity(value?.id ?? 0);
                    handleChange(
                      language as Language,
                      {
                        city_id: value?.id ?? 0,
                      },
                      true
                    );
                  }}
                  renderInput={(params) => (
                    <TextField {...params} label="Город" />
                  )}
                />

                <TextField
                  label="Координаты"
                  value={coordinates}
                  onChange={(e) => {
                    const input = e.target.value;
                    setCoordinates(input); // показываем как есть

                    const [latStr, lonStr] = input.split(/\s+/); // учитываем любые пробелы

                    const lat = parseFloat(latStr);
                    const lon = parseFloat(lonStr);

                    // Проверка, что обе координаты валидные числа
                    const isValidLat = !isNaN(lat);
                    const isValidLon = !isNaN(lon);

                    if (isValidLat && isValidLon) {
                      handleChange(language as Language, {
                        latitude: lat,
                        longitude: lon,
                      });
                    } else {
                      handleChange(language as Language, {
                        latitude: 0,
                        longitude: 0,
                      });
                    }
                  }}
                  fullWidth
                  variant="outlined"
                  placeholder="Введите координаты в формате: широта долгота"
                />
              </Box>

              <Box
                sx={{
                  display: "flex",

                  gap: 4,
                }}
              >
                <Box
                  sx={{
                    display: "flex",
                    justifyContent: "space-around",
                    width: "80%",
                    gap: 2,
                    flexDirection: { xs: "column", sm: "row" }, // Stack on extra small, side-by-side on small and up
                  }}
                >
                  <Paper
                    elevation={2}
                    sx={{
                      padding: 2,
                      display: "flex",
                      flexDirection: "column",
                      alignItems: "center",
                      gap: 1,
                      flex: 1,
                      minWidth: 150, // Ensure a minimum width
                    }}
                  >
                    <Box sx={{ display: "flex", alignItems: "center" }}>
                      <Typography
                        variant="subtitle2"
                        gutterBottom
                        sx={{ mb: 0, mr: 0.5 }}
                      >
                        Логотип
                      </Typography>
                    </Box>
                    <Box
                      sx={{
                        width: 80,
                        height: 80,
                        backgroundColor: "grey.200",
                        display: "flex",
                        alignItems: "center",
                        justifyContent: "center",
                        borderRadius: 1,
                        mb: 1,
                        cursor: common.thumbnail ? "pointer" : "default",
                        "&:hover": {
                          backgroundColor: common.thumbnail
                            ? "red.300"
                            : "grey.200",
                        },
                      }}
                      onClick={() => {
                        setIsMediaModalOpen(true);
                      }}
                    >
                      {common.thumbnail ? (
                        <img
                          src={`${import.meta.env.VITE_KRBL_MEDIA}${
                            common.thumbnail
                          }/download?token=${token}`}
                          alt="Логотип"
                          style={{ maxWidth: "100%", maxHeight: "100%" }}
                          onClick={() => {
                            setIsPreviewMediaOpen(true);
                            setMediaId(common.thumbnail);
                          }}
                        />
                      ) : (
                        <ImagePlus size={24} color="grey" />
                      )}
                    </Box>
                    <Button
                      variant="outlined"
                      size="small"
                      onClick={(e) => handleMenuOpen(e, "thumbnail")}
                    >
                      Выбрать
                    </Button>
                  </Paper>
                  <Paper
                    elevation={2}
                    sx={{
                      padding: 2,
                      display: "flex",
                      flexDirection: "column",
                      alignItems: "center",
                      gap: 1,
                      flex: 1,
                      minWidth: 150, // Ensure a minimum width
                    }}
                  >
                    <Box sx={{ display: "flex", alignItems: "center" }}>
                      <Typography
                        variant="subtitle2"
                        gutterBottom
                        sx={{ mb: 0, mr: 0.5 }}
                      >
                        Водяной знак (л.в)
                      </Typography>
                      <Tooltip title={"asf"}>
                        <Info
                          size={16}
                          color="gray"
                          style={{ cursor: "pointer" }}
                        />
                      </Tooltip>
                    </Box>
                    <Box
                      sx={{
                        width: 80,
                        height: 80,
                        backgroundColor: "grey.200",
                        display: "flex",
                        alignItems: "center",
                        justifyContent: "center",
                        borderRadius: 1,
                        mb: 1,
                        cursor: common.watermark_lu ? "pointer" : "default",
                        "&:hover": {
                          backgroundColor: common.watermark_lu
                            ? "grey.300"
                            : "grey.200",
                        },
                      }}
                      onClick={() => {
                        setIsPreviewMediaOpen(true);
                        setMediaId(common.watermark_lu);
                      }}
                    >
                      {common.watermark_lu ? (
                        <img
                          src={`${import.meta.env.VITE_KRBL_MEDIA}${
                            common.watermark_lu
                          }/download?token=${token}`}
                          alt="Знак л.в"
                          style={{ maxWidth: "100%", maxHeight: "100%" }}
                          onClick={() => {
                            setIsMediaModalOpen(true);
                            setMediaId(common.watermark_lu);
                          }}
                        />
                      ) : (
                        <ImagePlus size={24} color="grey" />
                      )}
                    </Box>
                    <Button
                      variant="outlined"
                      size="small"
                      onClick={(e) => handleMenuOpen(e, "watermark_lu")}
                    >
                      Выбрать
                    </Button>
                  </Paper>

                  <Paper
                    elevation={2}
                    sx={{
                      padding: 2,
                      display: "flex",
                      flexDirection: "column",
                      alignItems: "center",
                      gap: 1,
                      flex: 1,
                      minWidth: 150, // Ensure a minimum width
                    }}
                  >
                    <Box sx={{ display: "flex", alignItems: "center" }}>
                      <Typography
                        variant="subtitle2"
                        gutterBottom
                        sx={{ mb: 0, mr: 0.5 }}
                      >
                        Водяной знак (п.в)
                      </Typography>
                      <Tooltip title={"asfaf"}>
                        <Info
                          size={16}
                          color="gray"
                          style={{ cursor: "pointer" }}
                        />
                      </Tooltip>
                    </Box>
                    <Box
                      sx={{
                        width: 80,
                        height: 80,
                        backgroundColor: "grey.200",
                        display: "flex",
                        alignItems: "center",
                        justifyContent: "center",
                        borderRadius: 1,
                        mb: 1,
                        cursor: common.watermark_rd ? "pointer" : "default",
                        "&:hover": {
                          backgroundColor: common.watermark_rd
                            ? "grey.300"
                            : "grey.200",
                        },
                      }}
                      onClick={() => {
                        setIsMediaModalOpen(true);
                        setMediaId(common.watermark_rd);
                      }}
                    >
                      {common.watermark_rd ? (
                        <img
                          src={`${import.meta.env.VITE_KRBL_MEDIA}${
                            common.watermark_rd
                          }/download?token=${token}`}
                          alt="Знак п.в"
                          style={{ maxWidth: "100%", maxHeight: "100%" }}
                          onClick={() => {
                            setIsPreviewMediaOpen(true);
                            setMediaId(common.watermark_rd);
                          }}
                        />
                      ) : (
                        <ImagePlus size={24} color="grey" />
                      )}
                    </Box>
                    <Button
                      variant="outlined"
                      size="small"
                      onClick={(e) => handleMenuOpen(e, "watermark_rd")}
                    >
                      Выбрать
                    </Button>
                  </Paper>
                </Box>
              </Box>
            </Box>

            {/* LanguageSwitcher positioned at the top right */}

            <LanguageSwitcher />

            {/* Save Button fixed at the bottom right */}
            <Box
              sx={{
                position: "absolute",
                bottom: 0,
                right: 0,
                padding: 2,
                backgroundColor: "background.paper", // To ensure it stands out over content
                width: "100%", // Take full width to cover content below it
                display: "flex",
                justifyContent: "flex-end", // Align to the right
              }}
            >
              <Button
                variant="contained"
                color="success"
                onClick={() => {
                  console.log(sight);
                }}
              >
                Сохранить
              </Button>
            </Box>
          </Box>
        </TabPanel>

        {/* Media Menu */}
        <MuiMenu
          anchorEl={menuAnchorEl}
          open={Boolean(menuAnchorEl)}
          onClose={handleMenuClose}
          anchorOrigin={{
            vertical: "top",
            horizontal: "right",
          }}
          transformOrigin={{
            vertical: "bottom",
            horizontal: "right",
          }}
        >
          <MenuItem onClick={handleCreateNew}>Создать новую</MenuItem>
          <MenuItem onClick={handleAddMedia}>Выбрать существующую</MenuItem>
        </MuiMenu>

        <SelectMediaDialog
          open={isAddMediaOpen}
          onClose={() => {
            setIsAddMediaOpen(false);
            setActiveMenuType(null);
          }}
          onSelectMedia={handleMediaSelect}
        />

        <PreviewMediaDialog
          open={isPreviewMediaOpen}
          onClose={() => setIsPreviewMediaOpen(false)}
          mediaId={mediaId}
        />
      </>
    );
  }
);
